VOCAB_FILE = 'vocab.txt'
VOCAB_JSON_FILE = 'vocab.json'
MERGES_FILE = 'merges.txt'
SP_MODEL_FILE = 'spiece.model'
TOKENIZER_JSON_FILE = 'tokenizer.json'
SPECIAL_TOKENS_NAME = 'special_tokens.txt'
SPECIAL_TOKENS_MAP = 'special_tokens_map.json'